@@ -14,10 +14,10 @@ import copy
 import traceback
 
 import inspect
-from RIC import RememberInstanceCreationInfo
+from .RIC import RememberInstanceCreationInfo
 
-import linfit
-import uprint
+from . import linfit
+from . import uprint
 
 
 UF = "<class 'uncertainties.core.Variable'>"
