@@ -14,8 +14,8 @@ import platform  # windows 확인용
 
 import copy  # 복사용
 
-from exp import *
-from linfit import *
+from .exp import *
+from .linfit import *
 
 
 UF = "<class 'uncertainties.core.Variable'>"
